
# 0.5.4 (November 2023)

- Fix path/to/image when exporting Plate images ([#146](https://github.com/ome/omero-cli-zarr/pull/146))


# 0.5.3 (May 2023)

- Fix dimension separator in downsampled data ([#144](https://github.com/ome/omero-cli-zarr/pull/144))


# 0.5.2 (May 2023)

- Remove numpy.bool alias ([#143](https://github.com/ome/omero-cli-zarr/pull/143))

# 0.5.1 (November 2022)

- Fix axes "units" to "unit" ([#131](https://github.com/ome/omero-cli-zarr/pull/131))
